==> metasploit-4.0.0.tbz: share/metasploit/lib/msf/ui/banner.rb <==
module Msf
module Ui

###
#
# Module that contains some most excellent banners.
#
###
module Banner

	Logos =
		[
%Q{
%whiCall trans opt: received. 2-19-98 13:24:18 REC:Loc

     Trace program: running

           wake up, Neo...
        %bldthe matrix has you%clr
      follow the white rabbit.

          knock, knock, Neo.

                        (`.         ,-,
                        ` `.    ,;' /
                         `.  ,'/ .'
                          `. X /.'
                .-;--''--.._` ` (
              .'            /   `
             ,           ` '   Q '
             ,         ,   `._    \\
          ,.|         '     `-.;_'
          :  . `  ;    `  ` --,.._;
           ' `    ,   )   .'
              `._ ,  '   /_
                 ; ,''-,;' ``-
                  ``-..__``--`
%clr},

%Q{%whi
                 _---------.
             .' #######   ;."
  .---,.    ;@             @@`;   .---,..
." @@@@@'.,'@@            @@@@@',.'@@@@ ".
'-.@@@@@@@@@@@@@          @@@@@@@@@@@@@ @;
   `.@@@@@@@@@@@@        @@@@@@@@@@@@@@ .'
     "--'.@@@  -.@        @ ,'-   .'--"
          ".@' ; @       @ `.  ;'
            |@@@@ @@@     @    .
             ' @@@ @@   @@    ,
              `.@@@@    @@   .
                ',@@     @   ;           _____________
                 (   3 C    )     /|___ / Metasploit! \\
                 ;@'. __*__,."    \\|--- \\_____________/
                  '(.,...."/
%clr},
'
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%     %%%         %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  %%  %%%%%%%%   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  %  %%%%%%%%   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  %%  %%%%%%   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  %%%%%%%%%   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%  %%%  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%    %%   %%%%%%%%%%%  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  %%%  %%%%%
%%%%  %%  %%  %      %%      %%    %%%%%      %    %%%%  %%   %%%%%%       %%
%%%%  %%  %%  %  %%% %%%%  %%%%  %%  %%%%  %%%%  %% %%  %% %%% %%  %%%  %%%%%
%%%%  %%%%%%  %%   %%%%%%   %%%%  %%%  %%%%  %%    %%  %%% %%% %%   %%  %%%%%
%%%%%%%%%%%% %%%%     %%%%%    %%  %%   %    %%  %%%%  %%%%   %%%   %%%     %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  %%%%%%% %%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%          %%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
',
'
 _                                                      _
/  \\  / \\        __                          _   __    /_/ __
| |\\ /  | _____  \\ \\            ___   _____ | | /   \\  _   \\ \\
| | \\/| | | ___\\ |- -|   /\\    / __\\ | -__/ | | | |  || | |- -|
|_|   | | | _|__  | |_  / -\\ __\\ \\   | |    | |_ \__/ | |  | |_
      |/  |____/  \\___\\/ /\\  \\___/   \\/      \\__|     |_\\  \\___\\
',
%Q{
%whiIIIIII    %reddTb.dTb%clr        _.---._
%whi  II     %red4'  v  'B%clr   .'"".'/|\`.""'.
%whi  II     %red6.     .P%clr  :  .' / | \ `.  :
%whi  II     %red'T;. .;P'%clr  '.'  /  |  \  `.'
%whi  II      %red'T; ;P'%clr    `. /   |   \ .'
%whiIIIIII     %red'YvP'%clr       `-.__|__.-'

I love shells --egypt
},
'
     ,           ,
    /             \
   ((__---,,,---__))
      (_) O O (_)_________
         \ _ /            |\
          o_o \   M S F   | \
               \   _____  |  *
                |||   WW|||
                |||     |||
',
'
# cowsay++
 ____________
< metasploit >
 ------------
       \   ,__,
        \  (oo)____
           (__)    )\
              ||--|| *
',


'%clr
 ______________________________________________________________________________
|                                                                              |
|                          %bld3Kom SuperHack II Logon%clr                             |
|______________________________________________________________________________|
|                                                                              |
|                                                                              |
|                                                                              |
|                 User Name:          [   %redsecurity%clr    ]                        |
|                                                                              |
|                 Password:           [               ]                        |
|                                                                              |
|                                                                              |
|                                                                              |
|                                   %bld[ OK ]%clr                                     |
|______________________________________________________________________________|
|                                                                              |
|______________________________________________________________________________|
%clr
',


'%clr
 ______________________________________________________________________________
|                                                                              |
|                   %bld%grnMETASPLOIT CYBER MISSILE COMMAND V4%clr                        |
|______________________________________________________________________________|
      %yel\%clr                                  %yel/%clr                      %yel/%clr
       %yel\%clr     .                          %yel/%clr                      %yel/%clr            x
        %yel\%clr                              %yel/%clr                      %yel/%clr
         %yel\%clr                            %yel/%clr          +           %yel/%clr
          %yel\%clr            +             %yel/%clr                      %yel/%clr
           *                        %yel/%clr                      %yel/%clr
                                   %yel/%clr      .               %yel/%clr
    X                             %yel/%clr                      %yel/%clr            X
                                 %yel/%clr                     %red###%clr
                                %yel/%clr                     %red# %bld%%clr%red #%clr
                               %yel/%clr                       %red###%clr
                      .       %yel/%clr
     .                       %yel/%clr      .            %red*%clr           .
                            %yel/%clr
                           *
                  +                       %red*%clr

                                       %bld^%clr
####      __     __     __          #######         __     __     __        ####
####    %yel/%clr    %yel\%clr %yel/%clr    %yel\%clr %yel/%clr    %yel\%clr      ###########     %yel/%clr    %yel\%clr %yel/%clr    %yel\%clr %yel/%clr    %yel\%clr      ####
################################################################################
################################################################################
# %bldWAVE 4%clr ######## %bldSCORE 31337%clr ################################## %bldHIGH FFFFFFFF%clr #
################################################################################
%clr
',


'
%clr%whi
Unable to handle kernel NULL pointer dereference at virtual address 0xd34db33f
EFLAGS: 00010046
eax: 00000001 ebx: f77c8c00 ecx: 00000000 edx: f77f0001
esi: 803bf014 edi: 8023c755 ebp: 80237f84 esp: 80237f60
ds: 0018   es: 0018  ss: 0018
Process Swapper (Pid: 0, process nr: 0, stackpage=80377000)

%bld
Stack: 90909090990909090990909090
       90909090990909090990909090
       90909090.90909090.90909090
       90909090.90909090.90909090
       90909090.90909090.09090900
       90909090.90909090.09090900
       ..........................
       cccccccccccccccccccccccccc
       cccccccccccccccccccccccccc
       ccccccccc.................
       cccccccccccccccccccccccccc
       cccccccccccccccccccccccccc
       .................ccccccccc
       cccccccccccccccccccccccccc
       cccccccccccccccccccccccccc
       ..........................
       ffffffffffffffffffffffffff
       ffffffff..................
       ffffffffffffffffffffffffff
       ffffffff..................
       ffffffff..................
       ffffffff..................
%clr

%yelCode: 00 00 00 00 M3 T4 SP L0 1T FR 4M 3W OR K! V3 R5 I0 N4 00 00 00 00%clr
Aiee, Killing Interrupt handler
%redKernel panic: Attempted to kill the idle task!
In swapper task - not syncing
%clr
',
'
%clr
%bluMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMM%clr
%bluMMMMMMMMMMM                MMMMMMMMMM%clr
%bluMMMN$                           vMMMM%clr
%bluMMMNl%clr  %bldMMMMM             MMMMM%clr  %bluJMMMM%clr
%bluMMMNl%clr  %bldMMMMMMMN       NMMMMMMM%clr  %bluJMMMM%clr
%bluMMMNl%clr  %bldMMMMMMMMMNmmmNMMMMMMMMM%clr  %bluJMMMM%clr
%bluMMMNI%clr  %bldMMMMMMMMMMMMMMMMMMMMMMM%clr  %blujMMMM%clr
%bluMMMNI%clr  %bldMMMMMMMMMMMMMMMMMMMMMMM%clr  %blujMMMM%clr
%bluMMMNI%clr  %bldMMMMM   MMMMMMM   MMMMM%clr  %blujMMMM%clr
%bluMMMNI%clr  %bldMMMMM   MMMMMMM   MMMMM%clr  %blujMMMM%clr
%bluMMMNI%clr  %bldMMMNM   MMMMMMM   MMMMM%clr  %blujMMMM%clr
%bluMMMNI%clr  %bldWMMMM   MMMMMMM   MMMM#%clr  %bluJMMMM%clr
%bluMMMMR%clr  %bld?MMNM             MMMMM%clr %blu.dMMMM%clr
%bluMMMMNm%clr %bld`?MMM             MMMM`%clr %bludMMMMM%clr
%bluMMMMMMN%clr  %bld?MM             MM?%clr  %bluNMMMMMN%clr
%bluMMMMMMMMNe%clr                 %bluJMMMMMNMMM%clr
%bluMMMMMMMMMMNm,%clr            %blueMMMMMNMMNMM%clr
%bluMMMMNNMNMMMMMNx%clr        %bluMMMMMMNMMNMMNM%clr
%bluMMMMMMMMNMMNMMMMm+..+MMNMMNMNMMNMMNMM%clr
%clr
',
'
%clr                          ########                  #
                      #################            #
                   ######################         #
                  #########################      #
                ############################
               ##############################
               ###############################
              ###############################
              ##############################
                              #    ########   #
                 %red##%clr        %red###%clr        ####   ##
                                      ###   ###
                                    ####   ###
               ####          ##########   ####
               #######################   ####
                 ####################   ####
                  ##################  ####
                    ############      ##
                       ########        ###
                      #########        #####
                    ############      ######
                   ########      #########
                     #####       ########
                       ###       #########
                      ######    ############
                     #######################
                     #   #   ###  #   #   ##
                     ########################
                      ##     ##   ##     ##
%clr
'
		]


	#
	# Returns a random metasploit logo.
	#
	def self.to_s
		if ENV['GOCOW']
			case rand(2)
				when 0
					Logos[1]
				when 1
					Logos[5]
			end
		else
			Logos[rand(Logos.length)]
		end
	end

end

end
end

==> metasploit-4.5.0.tbz: share/metasploit/lib/msf/ui/banner.rb <==
# -*- coding: binary -*-
module Msf
module Ui

###
#
# Module that contains some most excellent banners.
#
###
module Banner

	Logos =
		[
%Q{
%whiCall trans opt: received. 2-19-98 13:24:18 REC:Loc

     Trace program: running

           wake up, Neo...
        %bldthe matrix has you%clr
      follow the white rabbit.

          knock, knock, Neo.

                        (`.         ,-,
                        ` `.    ,;' /
                         `.  ,'/ .'
                          `. X /.'
                .-;--''--.._` ` (
              .'            /   `
             ,           ` '   Q '
             ,         ,   `._    \\
          ,.|         '     `-.;_'
          :  . `  ;    `  ` --,.._;
           ' `    ,   )   .'
              `._ ,  '   /_
                 ; ,''-,;' ``-
                  ``-..__``--`
%clr},

%Q{%whi
                 _---------.
             .' #######   ;."
  .---,.    ;@             @@`;   .---,..
." @@@@@'.,'@@            @@@@@',.'@@@@ ".
'-.@@@@@@@@@@@@@          @@@@@@@@@@@@@ @;
   `.@@@@@@@@@@@@        @@@@@@@@@@@@@@ .'
     "--'.@@@  -.@        @ ,'-   .'--"
          ".@' ; @       @ `.  ;'
            |@@@@ @@@     @    .
             ' @@@ @@   @@    ,
              `.@@@@    @@   .
                ',@@     @   ;           _____________
                 (   3 C    )     /|___ / Metasploit! \\
                 ;@'. __*__,."    \\|--- \\_____________/
                  '(.,...."/
%clr},
'
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%     %%%         %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  %%  %%%%%%%%   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  %  %%%%%%%%   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  %%  %%%%%%   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  %%%%%%%%%   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%  %%%  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%    %%   %%%%%%%%%%%  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  %%%  %%%%%
%%%%  %%  %%  %      %%      %%    %%%%%      %    %%%%  %%   %%%%%%       %%
%%%%  %%  %%  %  %%% %%%%  %%%%  %%  %%%%  %%%%  %% %%  %% %%% %%  %%%  %%%%%
%%%%  %%%%%%  %%   %%%%%%   %%%%  %%%  %%%%  %%    %%  %%% %%% %%   %%  %%%%%
%%%%%%%%%%%% %%%%     %%%%%    %%  %%   %    %%  %%%%  %%%%   %%%   %%%     %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  %%%%%%% %%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%          %%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
',
'
 _                                                    _
/ \    /\         __                         _   __  /_/ __
| |\  / | _____   \ \           ___   _____ | | /  \ _   \ \
| | \/| | | ___\ |- -|   /\    / __\ | -__/ | || | || | |- -|
|_|   | | | _|__  | |_  / -\ __\ \   | |    | | \__/| |  | |_
      |/  |____/  \___\/ /\ \\\\___/   \/     \__|    |_\  \___\
',
%Q{
%whiIIIIII    %reddTb.dTb%clr        _.---._
%whi  II     %red4'  v  'B%clr   .'"".'/|\`.""'.
%whi  II     %red6.     .P%clr  :  .' / | \ `.  :
%whi  II     %red'T;. .;P'%clr  '.'  /  |  \  `.'
%whi  II      %red'T; ;P'%clr    `. /   |   \ .'
%whiIIIIII     %red'YvP'%clr       `-.__|__.-'

I love shells --egypt
},
'
     ,           ,
    /             \
   ((__---,,,---__))
      (_) O O (_)_________
         \ _ /            |\
          o_o \   M S F   | \
               \   _____  |  *
                |||   WW|||
                |||     |||
',
'
# cowsay++
 ____________
< metasploit >
 ------------
       \   ,__,
        \  (oo)____
           (__)    )\
              ||--|| *
',


'%clr
 ______________________________________________________________________________
|                                                                              |
|                          %bld3Kom SuperHack II Logon%clr                             |
|______________________________________________________________________________|
|                                                                              |
|                                                                              |
|                                                                              |
|                 User Name:          [   %redsecurity%clr    ]                        |
|                                                                              |
|                 Password:           [               ]                        |
|                                                                              |
|                                                                              |
|                                                                              |
|                                   %bld[ OK ]%clr                                     |
|______________________________________________________________________________|
|                                                                              |
|______________________________________________________________________________|
%clr
',


'%clr
 ______________________________________________________________________________
|                                                                              |
|                   %bld%grnMETASPLOIT CYBER MISSILE COMMAND V4%clr                        |
|______________________________________________________________________________|
      %yel\%clr                                  %yel/%clr                      %yel/%clr
       %yel\%clr     .                          %yel/%clr                      %yel/%clr            x
        %yel\%clr                              %yel/%clr                      %yel/%clr
         %yel\%clr                            %yel/%clr          +           %yel/%clr
          %yel\%clr            +             %yel/%clr                      %yel/%clr
           *                        %yel/%clr                      %yel/%clr
                                   %yel/%clr      .               %yel/%clr
    X                             %yel/%clr                      %yel/%clr            X
                                 %yel/%clr                     %red###%clr
                                %yel/%clr                     %red# %bld%%clr%red #%clr
                               %yel/%clr                       %red###%clr
                      .       %yel/%clr
     .                       %yel/%clr      .            %red*%clr           .
                            %yel/%clr
                           *
                  +                       %red*%clr

                                       %bld^%clr
####      __     __     __          #######         __     __     __        ####
####    %yel/%clr    %yel\%clr %yel/%clr    %yel\%clr %yel/%clr    %yel\%clr      ###########     %yel/%clr    %yel\%clr %yel/%clr    %yel\%clr %yel/%clr    %yel\%clr      ####
################################################################################
################################################################################
# %bldWAVE 4%clr ######## %bldSCORE 31337%clr ################################## %bldHIGH FFFFFFFF%clr #
################################################################################
%clr
',


'
%clr%whi
Unable to handle kernel NULL pointer dereference at virtual address 0xd34db33f
EFLAGS: 00010046
eax: 00000001 ebx: f77c8c00 ecx: 00000000 edx: f77f0001
esi: 803bf014 edi: 8023c755 ebp: 80237f84 esp: 80237f60
ds: 0018   es: 0018  ss: 0018
Process Swapper (Pid: 0, process nr: 0, stackpage=80377000)

%bld
Stack: 90909090990909090990909090
       90909090990909090990909090
       90909090.90909090.90909090
       90909090.90909090.90909090
       90909090.90909090.09090900
       90909090.90909090.09090900
       ..........................
       cccccccccccccccccccccccccc
       cccccccccccccccccccccccccc
       ccccccccc.................
       cccccccccccccccccccccccccc
       cccccccccccccccccccccccccc
       .................ccccccccc
       cccccccccccccccccccccccccc
       cccccccccccccccccccccccccc
       ..........................
       ffffffffffffffffffffffffff
       ffffffff..................
       ffffffffffffffffffffffffff
       ffffffff..................
       ffffffff..................
       ffffffff..................
%clr

%yelCode: 00 00 00 00 M3 T4 SP L0 1T FR 4M 3W OR K! V3 R5 I0 N4 00 00 00 00%clr
Aiee, Killing Interrupt handler
%redKernel panic: Attempted to kill the idle task!
In swapper task - not syncing
%clr
',
'
%clr
%bluMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMM%clr
%bluMMMMMMMMMMM                MMMMMMMMMM%clr
%bluMMMN$                           vMMMM%clr
%bluMMMNl%clr  %bldMMMMM             MMMMM%clr  %bluJMMMM%clr
%bluMMMNl%clr  %bldMMMMMMMN       NMMMMMMM%clr  %bluJMMMM%clr
%bluMMMNl%clr  %bldMMMMMMMMMNmmmNMMMMMMMMM%clr  %bluJMMMM%clr
%bluMMMNI%clr  %bldMMMMMMMMMMMMMMMMMMMMMMM%clr  %blujMMMM%clr
%bluMMMNI%clr  %bldMMMMMMMMMMMMMMMMMMMMMMM%clr  %blujMMMM%clr
%bluMMMNI%clr  %bldMMMMM   MMMMMMM   MMMMM%clr  %blujMMMM%clr
%bluMMMNI%clr  %bldMMMMM   MMMMMMM   MMMMM%clr  %blujMMMM%clr
%bluMMMNI%clr  %bldMMMNM   MMMMMMM   MMMMM%clr  %blujMMMM%clr
%bluMMMNI%clr  %bldWMMMM   MMMMMMM   MMMM#%clr  %bluJMMMM%clr
%bluMMMMR%clr  %bld?MMNM             MMMMM%clr %blu.dMMMM%clr
%bluMMMMNm%clr %bld`?MMM             MMMM`%clr %bludMMMMM%clr
%bluMMMMMMN%clr  %bld?MM             MM?%clr  %bluNMMMMMN%clr
%bluMMMMMMMMNe%clr                 %bluJMMMMMNMMM%clr
%bluMMMMMMMMMMNm,%clr            %blueMMMMMNMMNMM%clr
%bluMMMMNNMNMMMMMNx%clr        %bluMMMMMMNMMNMMNM%clr
%bluMMMMMMMMNMMNMMMMm+..+MMNMMNMNMMNMMNMM%clr
%clr
',
'
%clr                          ########                  #
                      #################            #
                   ######################         #
                  #########################      #
                ############################
               ##############################
               ###############################
              ###############################
              ##############################
                              #    ########   #
                 %red##%clr        %red###%clr        ####   ##
                                      ###   ###
                                    ####   ###
               ####          ##########   ####
               #######################   ####
                 ####################   ####
                  ##################  ####
                    ############      ##
                       ########        ###
                      #########        #####
                    ############      ######
                   ########      #########
                     #####       ########
                       ###       #########
                      ######    ############
                     #######################
                     #   #   ###  #   #   ##
                     ########################
                      ##     ##   ##     ##
%clr
',
%Q{
  %whi+-------------------------------------------------------+
  %whi|  METASPLOIT by Rapid7                                 |
  %whi+---------------------------+---------------------------+
  %whi|      %blu__________________   %whi|                           |
  %whi|  %yel==c%blu(______(%yelo%blu(______(_%yel()  %whi| %grn|""""""""""""|======\[%red***  %whi|
  %whi|             %blu)%yel=%blu\\\           %whi| %grn|  %whiEXPLOIT   %grn\\            %whi|
  %whi|            %blu// \\\\          %whi| %grn|_____________\\_______    %whi|
  %whi|           %blu//   \\\\         %whi| %grn|==\[%whimsf >%grn\]============\\   %whi|
  %whi|          %blu//     \\\\        %whi| %grn|______________________\\  %whi|
  %whi|         %blu// %whiRECON %blu\\\\       %whi| %grn\\(@)(@)(@)(@)(@)(@)(@)/   %whi|
  %whi|        %blu//         \\\\      %whi|  %grn*********************    %whi|
  %whi+---------------------------+---------------------------+
  %whi|      o O o                |        %yel\\'\\/\\/\\/'/         %whi|
  %whi|              o O          |         %yel)%whi======%yel(          %whi|
  %whi|                 o         |       %yel.'  %whiLOOT  %yel'.        %whi|
  %whi| %red|^^^^^^^^^^^^^^\|l%red___      %whi|      %yel/    %grn_||__   %yel\\       %whi|
  %whi| %red|    %whiPAYLOAD     %red|%whi""\\%red___, %whi|     %yel/    %grn(_||_     %yel\\      %whi|
  %whi| %red|________________|__|)__| %whi|    %yel|     %grn__||_)     %yel|     %whi|
  %whi| %red|(@)(@)"""**|(@)(@)**|(@) %whi|    %yel"       %grn||       %yel"     %whi|
  %whi|  %yel= = = = = = = = = = = =  %whi|     %yel'--------------'      %whi|
  %whi+---------------------------+---------------------------+%clr
  %clr
},]




	#
	# Returns a random metasploit logo.
	#
	def self.to_s
		if ENV['GOCOW']
			case rand(2)
				when 0
					Logos[1]
				when 1
					Logos[5]
			end
		else
			Logos[rand(Logos.length)]
		end
	end

end

end
end
